@@ -1,4 +1,4 @@
-#include "path.h"
+#include "fs.h"
 
 #include <stdbool.h>
 #include <sys/types.h>
