@@ -8,5 +8,5 @@
 #define WRITE_STR(fd, s) write(fd, s, strlen(s))
 
 
-bool err(const char *msg, bool sys, const char *id);
-void die(const char *msg, bool sys, const char *id);
+bool err(const char *msg, int syserr, const char *id);
+void die(const char *msg, int syserr, const char *id);
